@@ -1,5 +1,5 @@
 /* cat -- concatenate files and print on the standard output.
-   Copyright (C) 1988, 1990, 1991, 1995 Free Software Foundation, Inc.
+   Copyright (C) 88, 90, 91, 95, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,7 +31,6 @@
 #include <sys/ioctl.h>
 #endif
 #include "system.h"
-#include "version.h"
 #include "error.h"
 
 /* Undefine, to avoid warning about redefinition on some systems.  */
@@ -73,7 +72,7 @@ static char *line_num_end = line_buf + 10;
 static int newlines2 = 0;
 
 /* Count of non-fatal error conditions.  */
-static int exit_stat = 0;
+static int exit_status = 0;
 
 static void
 usage (int status)
@@ -106,7 +105,7 @@ Concatenate FILE(s), or standard input, to standard output.\n\
 With no FILE, or when FILE is -, read standard input.\n\
 "));
     }
-  exit (status);
+  exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
 /* Compute the next line number.  */
@@ -152,7 +151,7 @@ simple_cat (
       if (n_read < 0)
 	{
 	  error (0, errno, "%s", infile);
-	  exit_stat = 1;
+	  exit_status = 1;
 	  return;
 	}
 
@@ -164,7 +163,7 @@ simple_cat (
       /* Write this block out.  */
 
       if (full_write (output_desc, buf, n_read) < 0)
-	error (1, errno, _("write error"));
+	error (EXIT_FAILURE, errno, _("write error"));
     }
 }
 
@@ -245,7 +244,7 @@ cat (
 	      do
 		{
 		  if (full_write (output_desc, wp, outsize) < 0)
-		    error (1, errno, _("write error"));
+		    error (EXIT_FAILURE, errno, _("write error"));
 		  wp += outsize;
 		}
 	      while (bpout - wp >= outsize);
@@ -287,7 +286,7 @@ cat (
 		  else
 		    {
 		      error (0, errno, _("cannot do ioctl on `%s'"), infile);
-		      exit_stat = 1;
+		      exit_status = 1;
 		      newlines2 = newlines;
 		      return;
 		    }
@@ -298,7 +297,7 @@ cat (
 		  int n_write = bpout - outbuf;
 
 		  if (full_write (output_desc, outbuf, n_write) < 0)
-		    error (1, errno, _("write error"));
+		    error (EXIT_FAILURE, errno, _("write error"));
 		  bpout = outbuf;
 		}
 
@@ -308,7 +307,7 @@ cat (
 	      if (n_read < 0)
 		{
 		  error (0, errno, "%s", infile);
-		  exit_stat = 1;
+		  exit_status = 1;
 		  newlines2 = newlines;
 		  return;
 		}
@@ -439,7 +438,7 @@ cat (
     }
 }
 
-void
+int
 main (int argc, char **argv)
 {
   /* Optimal size of i/o operations of output.  */
@@ -505,6 +504,9 @@ main (int argc, char **argv)
   };
 
   program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
 
   /* Parse command line options.  */
 
@@ -571,14 +573,14 @@ main (int argc, char **argv)
 	  break;
 
 	default:
-	  usage (2);
+	  usage (EXIT_FAILURE);
 	}
     }
 
   if (show_version)
     {
-      printf ("cat - %s\n", version_string);
-      exit (0);
+      printf ("cat - %s\n", PACKAGE_VERSION);
+      exit (EXIT_SUCCESS);
     }
 
   if (show_help)
@@ -589,7 +591,7 @@ main (int argc, char **argv)
   /* Get device, i-node number, and optimal blocksize of output.  */
 
   if (fstat (output_desc, &stat_buf) < 0)
-    error (1, errno, _("standard output"));
+    error (EXIT_FAILURE, errno, _("standard output"));
 
   outsize = ST_BLKSIZE (stat_buf);
   /* Input file can be output file for non-regular files.
@@ -635,7 +637,7 @@ main (int argc, char **argv)
 	  if (input_desc < 0)
 	    {
 	      error (0, errno, "%s", infile);
-	      exit_stat = 1;
+	      exit_status = 1;
 	      continue;
 	    }
 	}
@@ -643,7 +645,7 @@ main (int argc, char **argv)
       if (fstat (input_desc, &stat_buf) < 0)
 	{
 	  error (0, errno, "%s", infile);
-	  exit_stat = 1;
+	  exit_status = 1;
 	  goto contin;
 	}
       insize = ST_BLKSIZE (stat_buf);
@@ -655,10 +657,10 @@ main (int argc, char **argv)
 
       if (check_redirection
 	  && stat_buf.st_dev == out_dev && stat_buf.st_ino == out_ino
-	  && (input_desc != fileno (stdin) || output_desc != fileno (stdout)))
+	  && (input_desc != STDIN_FILENO || output_desc != STDOUT_FILENO))
 	{
 	  error (0, 0, _("%s: input file is output file"), infile);
-	  exit_stat = 1;
+	  exit_status = 1;
 	  goto contin;
 	}
 
@@ -708,15 +710,15 @@ main (int argc, char **argv)
       if (strcmp (infile, "-") && close (input_desc) < 0)
 	{
 	  error (0, errno, "%s", infile);
-	  exit_stat = 1;
+	  exit_status = 1;
 	}
     }
   while (++argind < argc);
 
   if (have_read_stdin && close (0) < 0)
-    error (1, errno, "-");
+    error (EXIT_FAILURE, errno, "-");
   if (close (1) < 0)
-    error (1, errno, _("write error"));
+    error (EXIT_FAILURE, errno, _("write error"));
 
-  exit (exit_stat);
+  exit (exit_status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
