@@ -1,5 +1,5 @@
 /* GNU fmt -- simple text formatter.
-   Copyright (C) 1994, 1995 Free Software Foundation, Inc.
+   Copyright (C) 94, 95, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,7 +40,6 @@
 #define word unused_word_type
 
 #include "system.h"
-#include "version.h"
 #include "error.h"
 #include "xstrtol.h"
 
@@ -66,7 +65,7 @@
 
 typedef long COST;
 
-#define	MAXCOST	(~(((COST) 1) << (8 * sizeof (COST) -1)))
+#define	MAXCOST	(~(((unsigned long) 1) << (8 * sizeof (COST) -1)))
 
 #define	SQR(n)		((n) * (n))
 #define	EQUIV(n)	SQR ((COST) (n))
@@ -126,8 +125,10 @@ typedef long COST;
 /* Miscellaneous definitions.  */
 
 typedef unsigned int bool;
-#define	TRUE	1
-#define	FALSE	0
+#undef TRUE
+#define TRUE	1
+#undef FALSE
+#define FALSE	0
 
 /* Word descriptor structure.  */
 
@@ -300,7 +301,7 @@ Mandatory arguments to long options are mandatory for short options too.\n\
 In -wNUMBER, the letter `w' may be omitted.\n"),
 	     stdout);
     }
-  exit (status);
+  exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
 /* Decode options and launch execution.  */
@@ -325,6 +326,9 @@ main (register int argc, register char **argv)
   FILE *infile;
 
   program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
 
   crown = tagged = split = uniform = FALSE;
   max_width = WIDTH;
@@ -379,7 +383,7 @@ main (register int argc, register char **argv)
 	  long int tmp_long;
 	  if (xstrtol (optarg, NULL, 10, &tmp_long, NULL) != LONGINT_OK
 	      || tmp_long <= 0 || tmp_long > INT_MAX)
-	    error (1, 0, _("invalid line number increment: `%s'"),
+	    error (EXIT_FAILURE, 0, _("invalid line number increment: `%s'"),
 		   optarg);
 	  max_width = (int) tmp_long;
 	}
@@ -393,8 +397,8 @@ main (register int argc, register char **argv)
 
   if (show_version)
     {
-      printf ("fmt - %s\n", version_string);
-      exit (0);
+      printf ("fmt - %s\n", PACKAGE_VERSION);
+      exit (EXIT_SUCCESS);
     }
 
   if (show_help)
@@ -420,7 +424,7 @@ main (register int argc, register char **argv)
 	    error (0, errno, argv[optind]);
 	}
 
-  exit (0);
+  exit (EXIT_SUCCESS);
 }
 
 /* Trim space from the front and back of the string P, yielding the prefix,
@@ -571,8 +575,9 @@ copy_rest (FILE *f, register int c)
   if (in_column > next_prefix_indent && c != '\n' && c != EOF)
     {
       put_space (next_prefix_indent);
-      for (s = prefix; out_column != in_column; out_column++)
+      for (s = prefix; out_column != in_column && *s; out_column++)
 	putchar (*s++);
+      put_space (in_column - out_column);
     }
   while (c != '\n' && c != EOF)
     {
