@@ -1,5 +1,5 @@
 /* tail -- output the last part of file(s)
-   Copyright (C) 1989, 1990, 1991, 1995 Free Software Foundation, Inc.
+   Copyright (C) 89, 90, 91, 95, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -51,7 +51,6 @@
 #include <sys/types.h>
 
 #include "system.h"
-#include "version.h"
 #include "xstrtol.h"
 #include "error.h"
 
@@ -64,7 +63,7 @@
       assert ((fd) == 1);						\
       assert ((n_bytes) >= 0);						\
       if (n_bytes > 0 && fwrite ((buffer), 1, (n_bytes), stdout) == 0)	\
-	error (1, errno, _("write error"));				\
+	error (EXIT_FAILURE, errno, _("write error"));			\
     }									\
   while (0)
 
@@ -166,7 +165,7 @@ the [bkm] suffix multipliers, in which case it is treated like -c VALUE\n\
 or -c +VALUE.\n\
 "));
     }
-  exit (status);
+  exit (status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
 
 static void
@@ -538,7 +537,7 @@ output:
       total += bytes_read;
     }
   if (bytes_read == -1)
-    error (1, errno, "%s", filename);
+    error (EXIT_FAILURE, errno, "%s", filename);
   if (forever)
     {
       fflush (stdout);
@@ -837,7 +836,7 @@ tail_file (const char *filename, off_t n_units, int filenum)
   return errors;
 }
 
-void
+int
 main (int argc, char **argv)
 {
   enum header_mode header_mode = multiple_files;
@@ -848,16 +847,22 @@ main (int argc, char **argv)
   off_t n_units = -1;
   long int tmp_long;
   int c;			/* Option character.  */
-  int fileind;			/* Index in ARGV of first file name.  */
+  int n_files;
+  char **file;
 
   program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
+
   have_read_stdin = 0;
   count_lines = 1;
   forever = forever_multiple = from_start = print_headers = 0;
 
   if (argc > 1
       && ((argv[1][0] == '-' && ISDIGIT (argv[1][1]))
-	  || (argv[1][0] == '+' && (ISDIGIT (argv[1][1]) || argv[1][1] == 0))))
+	  || (argv[1][0] == '+' && (ISDIGIT (argv[1][1])
+				    || argv[1][1] == 0))))
     {
       /* Old option syntax: a dash or plus, one or more digits (zero digits
 	 are acceptable with a plus), and one or more option letters.  */
@@ -874,6 +879,11 @@ main (int argc, char **argv)
 	    {
 	      STRTOL_FATAL_ERROR (argv[1], _("argument"), s_err);
 	    }
+
+	  /* If a [bkm] suffix was given then count bytes, not lines.  */
+	  if (p[-1] == 'b' || p[-1] == 'k' || p[-1] == 'm')
+	    count_lines = 0;
+
 	  /* Parse any appended option letters.  */
 	  while (*p)
 	    {
@@ -966,8 +976,8 @@ main (int argc, char **argv)
 
   if (show_version)
     {
-      printf ("tail - %s\n", version_string);
-      exit (0);
+      printf ("tail - %s\n", PACKAGE_VERSION);
+      exit (EXIT_SUCCESS);
     }
 
   if (show_help)
@@ -985,32 +995,38 @@ main (int argc, char **argv)
 	--n_units;
     }
 
-  fileind = optind;
+  n_files = argc - optind;
+  file = argv + optind;
 
-  if (optind < argc - 1 && forever)
+  if (n_files > 1 && forever)
     {
       forever_multiple = 1;
       forever = 0;
-      file_descs = (int *) xmalloc ((argc - optind) * sizeof (int));
-      file_sizes = (off_t *) xmalloc ((argc - optind) * sizeof (off_t));
+      file_descs = (int *) xmalloc (n_files * sizeof (int));
+      file_sizes = (off_t *) xmalloc (n_files * sizeof (off_t));
     }
 
   if (header_mode == always
-      || (header_mode == multiple_files && optind < argc - 1))
+      || (header_mode == multiple_files && n_files > 1))
     print_headers = 1;
 
-  if (optind == argc)
-    exit_status |= tail_file ("-", n_units, 0);
+  if (n_files == 0)
+    {
+      exit_status |= tail_file ("-", n_units, 0);
+    }
+  else
+    {
+      int i;
+      for (i = 0; i < n_files; i++)
+	exit_status |= tail_file (file[i], n_units, i);
 
-  for (; optind < argc; ++optind)
-    exit_status |= tail_file (argv[optind], n_units, optind - fileind);
-
-  if (forever_multiple)
-    tail_forever (argv + fileind, argc - fileind);
+      if (forever_multiple)
+	tail_forever (file, n_files);
+    }
 
   if (have_read_stdin && close (0) < 0)
-    error (1, errno, "-");
+    error (EXIT_FAILURE, errno, "-");
   if (fclose (stdout) == EOF)
-    error (1, errno, _("write error"));
-  exit (exit_status);
+    error (EXIT_FAILURE, errno, _("write error"));
+  exit (exit_status == 0 ? EXIT_SUCCESS : EXIT_FAILURE);
 }
